@@ -1,5 +1,5 @@
 showChanges<-function(pkg="scrime"){
-	filename<-file.path(.find.package(pkg),"CHANGES")
+	filename<-file.path(find.package(pkg),"CHANGES")
 	file.show(filename)
 }
 
