@@ -91,10 +91,8 @@ simulateSNPcatResponse<-function(n.obs=1000,n.snp=50,list.ia=NULL,list.snp=NULL,
 	mat<-buildSNPmat(n.obs,n.snp,maf,vec.ias)
 	mat.prob <- matrix(0,n.obs,n.cat)
 	mat2<-as.data.frame(mat)
-	attach(mat2)
 	for(i in 1:n.cat)
-		mat.prob[,i]<-eval(parse(text=vec.models[i]))
-	detach(mat2)
+		mat.prob[,i]<-with(mat2, eval(parse(text=vec.models[i])))
 	ref.out <- if(withRef) getResponseRef(mat.prob, n.cat, n.obs, beta0, sample.y=sample.y)
 		else getResponseCat1(mat.prob, n.cat, n.obs, beta0, n.ias, sample.y=sample.y)
 	tab <- table(ref.out$vec.which, ref.out$cl)
